// You can import API functions like this from D3.js.
import { select, 
          csv , 
          scaleLinear,
          scaleTime,
          max,
          extent,
  			  format,
  				timeParse,
  				timeFormat,
          axisLeft} from 'd3';

import { hist } from './hist';
import { scatterPlot } from './line';

let svgHist = select('#histogram')
  .selectAll('svg')
  .data([null]);

svgHist = svgHist
  .enter()
  .append('svg')
    .attr('width', 1000)
    .attr('height', 500)
  .merge(svgHist);      

const gHist = svgHist
  .append('g')
  .attr('transform','translate(100,20)');

let svgLine = select('#line')
  .selectAll('svg')
  .data([null]);

svgLine = svgLine
  .enter()
  .append('svg')
    .attr('width', 1000)
    .attr('height', 500)
  .merge(svgLine);      

const gLine = svgLine
  .append('g')
  .attr('transform','translate(100,20)');
const parseDate = timeParse("%d/%m/%Y");
const formatDate = timeFormat("%b %d");

let data;

let selectedBar = null; 
const onClick = d => { 
  selectedBar = d;
  render();
}

const render = () => {
  hist(gHist,{data, 
          onClick,
          selectedBar
         }
       );
  scatterPlot(gLine,{data, 
          xValue : d => d.Date,
          yValue : d => d.Depth,
          circleRadius: 10,
          margin : { top: 20, right:40, bottom:180, left: 150 },
          title : 'GSI Borehole: Water levels by week',
          xAxisLabel : 'Date',
          yAxisLabel : 'Water level (mbgl)',
          innerWidth : 500 - 40 - 20,
          innerHeight : 500 - 10 - 40,
          selectedBar,
          onClick
         }
       ); 
}

csv('https://vizhub.com/careyshan/datasets/borehole_dummydata1.csv')
  .then(loadedData => {
    data = loadedData;
    data.forEach( d=> {
      d.Depth = +d.Depth;
      d.Date = parseDate(d.Date);
      d.type = 'Old'
  })
  render();
  
//   setTimeout(() => {
//     data.pop();
//    render()}, 2000)
  
//     setTimeout(() => {
//     data[1].Depth = 10;
//     data[1].type = 'New'  
//    render()}, 4000)
  
//       setTimeout(() => {
//     data[2].Depth = 20;
//     data[2].type = 'New'  
//    render()}, 6000)
});